@@ -80,7 +80,9 @@ class WizWalkerConsole(Monitor):
             self.write(f"Timeout error with coro {coro.__name__}")
             future.cancel()
         except Exception as exc:
-            self.write(f"Error in coro {coro.__name__}: {exc}")
+            import traceback
+
+            traceback.print_exception(type(exc), exc, exc.__traceback__)
         else:
             return result
 
@@ -134,7 +136,6 @@ class WizWalkerConsole(Monitor):
                 "health",
                 "mana",
                 "potions",
-                "potions_alt",
                 "gold",
                 "energy",
                 "backpack_space_used",
@@ -206,6 +207,17 @@ class WizWalkerConsole(Monitor):
 
         self.write("Completed click")
 
+    def do_onehook(self, name: str):
+        """Get clients and activate one hook"""
+        walker = self.get_local("walker")
+        walker.get_clients()
+        self.write(f"Attached to {len(walker.clients)} clients")
+
+        for client in walker.clients:
+            self.run_coro(client.activate_hooks(name))
+
+        self.write(f"Hooked {name} on all clients")
+
 
 def test_monitor():
     cli.monitor_client(cli.MONITOR_HOST, cli.MONITOR_PORT)
