@@ -29,6 +29,9 @@ class XYZ:
     def __sub__(self, other):
         return self.distance(other)
 
+    def __str__(self):
+        return f"({self.x}, {self.y}, {self.z})"
+
     def distance(self, other):
         """
         Calculate the distance between two points
@@ -140,14 +143,14 @@ def instance_login(window_handle: int, username: str, password: str):
 
     def send_chars(chars: str):
         for char in chars:
-            user32.PostMessageW(window_handle, 0x102, ord(char), 0)
+            user32.SendMessageW(window_handle, 0x102, ord(char), 0)
 
     send_chars(username)
     # tab
-    user32.PostMessageW(window_handle, 0x102, 9, 0)
+    user32.SendMessageW(window_handle, 0x102, 9, 0)
     send_chars(password)
     # enter
-    user32.PostMessageW(window_handle, 0x102, 13, 0)
+    user32.SendMessageW(window_handle, 0x102, 13, 0)
 
 
 async def start_instances_with_login(instance_number: int, logins: Iterable):
@@ -319,52 +322,6 @@ def pharse_template_id_file(file_data: bytes) -> dict:
     return out
 
 
-def pharse_message_file(file_data: bytes):
-    """
-    Pharse a message file's data
-    """
-    decoded = file_data.decode(errors="ignore")
-    root = ElementTree.fromstring(decoded)
-
-    service_data = root.find("_ProtocolInfo").find("RECORD")
-    service_id = int(service_data.find("ServiceID").text)
-    pharsed_service_data = {
-        "type": service_data.find("ProtocolType").text,
-        "description": service_data.find("ProtocolDescription").text,
-    }
-
-    messages = root[1:]
-
-    def msg_sorter(m):
-        # Function to sort messages by
-        return m[0].find("_MsgName").text
-
-    parsed_msgs = {}
-    for index, msg in enumerate(sorted(messages, key=msg_sorter), 1):
-        # msg[0] is the RECORD element
-        msg_data = msg[0]
-
-        msg_name = msg_data.find("_MsgName").text
-        msg_description = msg_data.find("_MsgDescription").text
-
-        params = []
-
-        for child in msg_data:
-            # Message meta info starts with _
-            if not child.tag.startswith("_"):
-                params.append({"name": child.tag, "type": child.get("TYPE")})
-
-        parsed_msgs[index] = {
-            "name": msg_name,
-            "description": msg_description,
-            "params": params,
-        }
-
-    pharsed_service_data["messages"] = parsed_msgs
-
-    return {service_id: pharsed_service_data}
-
-
 def pharse_node_data(file_data: bytes) -> dict:
     """
     Converts data into a dict of node nums to points
@@ -412,10 +369,10 @@ async def timed_send_key(window_handle: int, key: Keycode, seconds: float):
     keydown_task = asyncio.create_task(_send_keydown_forever(window_handle, key))
     await asyncio.sleep(seconds)
     keydown_task.cancel()
-    user32.PostMessageW(window_handle, 0x101, key.value, 0)
+    user32.SendMessageW(window_handle, 0x101, key.value, 0)
 
 
 async def _send_keydown_forever(window_handle: int, key: Keycode):
     while True:
-        user32.PostMessageW(window_handle, 0x100, key.value, 0)
+        user32.SendMessageW(window_handle, 0x100, key.value, 0)
         await asyncio.sleep(0.05)
